import type { I18n } from "vue-i18n"

import { isRef, watch, type Ref } from "vue"

import en from '~/locales/en.yaml'

let i18nInstance: I18n
const provideI18n = (i18n: I18n) => {
  if (!isRef(i18n.global.locale) || i18n.mode !== 'composition') {
    console.warn('[vui] locales won\'t be updated when provided i18n instance is in legacy mode')
    i18nInstance = i18n
    return
  }

  const globalMessages = i18n.global.messages as Ref<Record<string, typeof en>>
  watch(i18n.global.locale, async (locale, from) => {
    globalMessages.value[locale] ??= {}
    if ('vui' in globalMessages.value[locale]) return

    try {
      const { default: messages } = await import(`~/locales/${locale}.yaml`)
      globalMessages.value[locale] = { ...globalMessages.value[locale], ...messages }
    } catch (err) {
      console.warn(`[vui] Locale '${locale}' not found`)
    }
  }, { immediate: true })

  i18nInstance = i18n
}

const useI18nInstance = () => {
  return i18nInstance
}

export { provideI18n, useI18nInstance }
