import { computed } from "@vue/reactivity"
import { createGlobalState, resolveUnref, useWindowSize, type MaybeComputedRef } from "@vueuse/core"

const MOBILE_WIDTH = 640

export const useScreenSize = createGlobalState(() => useWindowSize({ includeScrollbar: false }))
export const isMobileView = (width?: MaybeComputedRef<number>) => {
  if (width === undefined) {
    const { width: screenWidth } = useScreenSize()
    width = screenWidth
  }

  return computed(() => (resolveUnref(width) ?? Infinity) <= MOBILE_WIDTH)
}
