import { createI18n, type I18n } from 'vue-i18n'
import type { App } from 'vue'

import '~/styles/funkwhale.scss'

import * as components from '~/components'
import { provideI18n } from './composables/useI18n'
import en from '~/locales/en.yaml'

export * from '~/components'

interface VuiOptions {
  i18n?: I18n
}

export default {
  install (app: App, options: VuiOptions = {}) {
    if (!options.i18n) {
      options.i18n = createI18n({
        legacy: false,
        locale: 'en',
        fallbackLocale: 'en',
        messages: { en }
      })

      app.use(options.i18n)
    }

    provideI18n(options.i18n)

    for (const prop in components) {
      const component = components[prop as keyof typeof components]
      app.component(prop, component)
    }
  }
}
